@@ -199,14 +199,13 @@ class Files {
 			// name="champ[tons][][sous][la][pluie][]"
 			// $_FILES[champ][error][tons][0][sous][la][pluie][0]
 			else {
+				include_spip('inc/filtres');
 				$chemins = Files::extraire_sous_chemins_fichiers($error);
 
-				foreach ($chemins['phps'] as $k => $chemin) {
+				foreach ($chemins['table_valeurs'] as $k => $chemin) {
 					$description = [];
 					foreach ($infos as $info) {
-						$var = '$_FILES[\'' . $racine . '\'][\'' . $info . '\']' . $chemin;
-						eval("\$x = $var;");
-						$description[$info] = $x;
+						$description[$info] = table_valeur($_FILES[$racine][$info], $chemin);
 					}
 
 					$complet = $racine . $chemins['names'][$k];
@@ -255,18 +254,16 @@ class Files {
 			// name="champ[tons][][sous][la][pluie][]"
 			// $_FILES[champ][error][tons][0][sous][la][pluie][0]
 			else {
+				include_spip('inc/filtres');
 				$chemins = Files::extraire_sous_chemins_fichiers($error);
 
-				foreach ($chemins['phps'] as $k => $chemin) {
-					$var = '$_FILES[\'' . $racine . '\'][\'error\']' . $chemin;
-					eval("\$error = $var;");
+				foreach ($chemins['table_valeurs'] as $k => $chemin) {
+					$error = table_valeur($_FILES[$racine]['error'], $chemin);
 
 					if ($error == 0) {
 						$description = [];
 						foreach ($infos as $info) {
-							$var = '$_FILES[\'' . $racine . '\'][\'' . $info . '\']' . $chemin;
-							eval("\$x = $var; unset($var);");
-							$description[$info] = $x;
+							$description[$info] = Files::unset_table_valeur($_FILES[$racine][$info], $chemin);
 						}
 
 						$complet = $racine . $chemins['names'][$k];
@@ -297,6 +294,7 @@ class Files {
 	public static function extraire_sous_chemins_fichiers($tableau) {
 		$listes = [
 			'phps' => [],   // ['tons'][0]['sous']['la']['pluie'][0]
+			'table_valeurs' => [],   // tons/0/sous/la/pluie/0
 			'reels' => [],  // [tons][0][sous][la][pluie][0]
 			'names' => [],  // [tons][][sous][la][pluie][]
 		];
@@ -307,7 +305,8 @@ class Files {
 
 		foreach ($tableau as $cle => $valeur) {
 			$reel = '[' . $cle . ']';
-			$php = is_int($cle) ? $reel : '[\'' . $cle . '\']';
+			$php = is_int($cle) ? $reel : '[\'' . addslashes($cle) . '\']';
+			$table_valeur = "$cle";
 
 			if ($cle === $i) {
 				$name = '[]';
@@ -320,6 +319,9 @@ class Files {
 				foreach ($ls['phps'] as $l) {
 					$listes['phps'][] = $php . $l;
 				}
+				foreach ($ls['table_valeurs'] as $l) {
+					$listes['table_valeurs'][] = $table_valeur . '/' . $l;
+				}
 				foreach ($ls['reels'] as $l) {
 					$listes['reels'][] = $reel . $l;
 				}
@@ -328,6 +330,7 @@ class Files {
 				}
 			} else {
 				$listes['phps'][] = $php;
+				$listes['table_valeurs'][] = $table_valeur;
 				$listes['reels'][] = $reel;
 				$listes['names'][] = $name;
 			}
@@ -336,4 +339,22 @@ class Files {
 
 		return $listes;
 	}
+
+	public static function unset_table_valeur(&$table, $chemin) {
+		$cles = explode('/', $chemin);
+		$last = array_pop($cles);
+		$t = &$table;
+		foreach ($cles as $k) {
+			if (!is_array($t) || !array_key_exists($k, $t)) {
+				return null; // rien a unset, le chemin n'existe pas dans la table
+			}
+			$t = &$t[$k];
+		}
+		if (!array_key_exists($last, $t)) {
+			return null;
+		}
+		$v = $t[$last];
+		unset($t[$last]);
+		return $v;
+	}
 }
