@@ -5,7 +5,7 @@
  * ------------------
  */
 
-define('_ECRAN_SECURITE', '1.6.3'); // 2024-08-19
+define('_ECRAN_SECURITE', '1.6.4'); // 2025-01-16
 
 /*
  * Documentation : https://www.spip.net/fr_article4200.html
@@ -711,6 +711,18 @@ if (
 	}
 }
 
+/*
+ *
+ * XSS API transmettre
+ */
+if (
+	isset($__request['action'])
+	and $__request['action'] == 'api_transmettre'
+	and isset($__request['arg'])
+	and strpos((string)$__request['arg'], '<') !== false
+) {
+	$ecran_securite_raison = "api_transmettre";
+}
 
 /*
  * S'il y a une raison de mourir, mourons
@@ -779,4 +791,4 @@ if (
 	die("<html><title>Status 429: Too Many Requests</title><body><h1>Status 429</h1><p>Too Many Requests (try again soon)</p></body></html>");
 }
 
-unset($__request);
+unset($__request);
\ No newline at end of file
