@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=rn
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_radio_articles_futurs' => 'ku nkuru zizokurikira(ntaco bihindura kuri SQL).',
@@ -17,5 +13,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'forum' => 'Ikiyago',
 
 	// R
-	'repondre_message' => 'Kwishura kuri ubu butumwa'
-);
+	'repondre_message' => 'Kwishura kuri ubu butumwa',
+];
